package services

import (
	"context"
	"fmt"
	"hongze/hongze_cygx/models"
	"hongze/hongze_cygx/utils"
	"strconv"
	"time"
)

//func init() {
//	UpdateCygxActivitySpecialSignupNum()
//}

//修改专项调研，用户与公司的参与数量
func UpdateCygxActivitySpecialSignupNum(cont context.Context) (err error) {
	defer func() {
		if err != nil {
			fmt.Println(err)
			go utils.SendAlarmMsg("修改活动状态至进行中失败"+err.Error(), 2)
			go utils.SendEmail(utils.APPNAME+"【"+utils.RunMode+"】"+"失败提醒", "修改活动状态至进行中失败 ErrMsg:"+err.Error(), utils.EmailSendToUsers)
		}
	}()
	//根据手机号分组获取列表以及数量
	var condition string
	var pars []interface{}
	condition += ` AND  s.create_time < ? `
	pars = append(pars, time.Now().Format(utils.FormatDate))
	listSpecial, err := models.GetActivityListSpecialGroupByMobile(condition, pars)
	if err != nil {
		return err
	}
	var mapMobile []string
	for _, v := range listSpecial {
		mapMobile = append(mapMobile, v.Mobile)
	}

	//根据手机号获取这些用户的信息
	userList, err := models.GetWxUserByMobiles(mapMobile)
	if err != nil {
		return err
	}

	//更改这些手机对应的关注关注数量
	err = models.UpdateActivitySpecialSignupNumMulti(listSpecial)
	if err != nil {
		return err
	}

	//更改这些手机对应的公司ID
	err = models.UpdateActivitySpecialSignupCompanyIdMulti(userList)
	if err != nil {
		return err
	}

	//根据CompanyId分组获取列表以及数量
	listSpecialByCompanyId, err := models.GetActivityListSpecialGroupByCompanyId(condition, pars)
	if err != nil {
		return err
	}

	//更改这些公司对应的关注关注数量
	err = models.UpdateActivitySpecialSignupCompanyNumMulti(listSpecialByCompanyId)
	if err != nil {
		return err
	}
	fmt.Println("UpdateCygxActivitySpecialSignupNum end")
	return
}

//处理专项调研的展示
func GetActivityLabelSpecialList(userType, isPower int, chartPermissionIds, scale, permissionNameStr string) (item *models.ActivityTypeHome, err error) {
	var condition string
	var pars []interface{}
	condition = ` AND art.publish_status = 1  AND art.label != '' `

	//行业名称
	if isPower == 1 {
		condition += ` AND art.chart_permission_name  IN (` + permissionNameStr + `) `
	}
	if chartPermissionIds != "" {
		condition += ` AND art.chart_permission_id  IN (` + chartPermissionIds + `) `
	}
	var conditionOr string
	if scale != "" {
		conditionOr += ` OR (  art.scale LIKE '%` + scale + `%'	 ` + condition + `) `
	}
	condition += ` AND  art.customer_type_ids LIKE '%` + strconv.Itoa(userType) + `%'` + conditionOr
	specialList, err := models.GetActivityLabelSpecialListAll(condition, pars, 0, 8)
	if err != nil {
		return
	}
	for k2, v2 := range specialList {
		specialList[k2].KeyWord = LabelStrV5(v2.KeyWord, v2.IsShowSubjectName, v2.TemporaryLabel)
		specialList[k2].ImgUrlBg = "https://hzstatic.hzinsights.com/static/temp/20220426202204/20220426/XDLLsjC9XAAy8LIzQr7GsjrBbtX6.png"
		specialList[k2].ImgUrlBg = utils.ACTIVITY_ZXDY_ImgUrl3
	}
	itemList := new(models.ActivityTypeHome)
	itemList.ActivityTypeName = "专项产业调研"
	itemList.Resource = 2
	itemList.List = specialList
	itemList.ActivityTypeId = 7
	itemList.ImgUrl = utils.ACTIVITY_ZXDY_ImgUrl1
	itemList.ImgUrlBg = utils.ACTIVITY_ZXDY_ImgUrl2
	item = itemList
	return
}
